"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.GlobalCounter = void 0;

require("core-js/modules/web.dom-collections.iterator.js");

var _react = _interopRequireWildcard(require("react"));

var _Counter = require("./Counter");

var _Constants = require("./Constants");

var _functions = require("./functions");

var _CounterPopup = require("./CounterPopup");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

const GlobalCounter = () => {
  const globalCounterRef = (0, _react.useRef)(null);
  const [treesSaved, setTreesSaved] = (0, _react.useState)((0, _functions.getTotalTreesSaved)());
  const [tabsOpened, setTabsOpened] = (0, _react.useState)(Math.ceil(Date.now() / 1000000));

  const secondsPerTabOpened = (0, _functions.getLocalStorage)(_Constants.STORAGE_SECONDS_PER_TAB_OPENED) || _Constants.DEFAULT_SECONDS_PER_TAB_OPENED;

  (0, _react.useEffect)(() => {
    const treeIncrementInterval = setInterval(() => {
      setTreesSaved(prevValue => prevValue + 1);
    }, _Constants.DEFAULT_SECONDS_PER_TREE_SAVED * 1000);
    return () => {
      clearInterval(treeIncrementInterval);
    };
  }, []);
  (0, _react.useEffect)(() => {
    const tabIncrementInterval = setInterval(() => {
      setTabsOpened(prevValue => prevValue + 1);
    }, secondsPerTabOpened * 1000);
    return () => {
      clearInterval(tabIncrementInterval);
    };
  }, []);
  const counterDataList = [{
    title: "Trees we have saved",
    image: _Constants.colourLogo,
    value: treesSaved
  }, {
    title: "Searches we have made",
    image: _Constants.tab,
    value: tabsOpened
  }, {
    title: "Tons of CO2 eq. we have stored",
    image: _Constants.cloud,
    value: (0, _functions.addCommas)((0, _functions.treesToCO2Stored)(treesSaved))
  }];

  const CounterHeader = () => /*#__PURE__*/_react.default.createElement(_react.default.Fragment, null, /*#__PURE__*/_react.default.createElement("span", null, (0, _functions.addCommas)(treesSaved)), " ", _Constants.globe);

  return /*#__PURE__*/_react.default.createElement("div", {
    className: "app-container counter",
    ref: globalCounterRef
  }, /*#__PURE__*/_react.default.createElement(_Counter.Counter, {
    togglePopup: () => {},
    header: /*#__PURE__*/_react.default.createElement(CounterHeader, null),
    popup: /*#__PURE__*/_react.default.createElement(_CounterPopup.CounterPopup, {
      dataList: counterDataList,
      type: "global"
    })
  }));
};

exports.GlobalCounter = GlobalCounter;