"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.fetchQuery = exports.copyValueToClipboard = exports.copyToClipboard = exports.arrayNotEmpty = exports.addCommas = exports.NumberFloor = void 0;
exports.getBrowserType = getBrowserType;
exports.getPercentageOfTreeSaved = exports.getLocalStorage = exports.getDefaultTotalTreesSaved = void 0;
exports.getPostHeader = getPostHeader;
exports.validUserId = exports.treesToCO2Stored = exports.sumOfTreesInList = exports.sumOfScoresInList = exports.stringNotEmpty = exports.setLocalStorage = exports.positionCursorFocus = exports.numberOfAdsToTreeSavedSource = exports.leadershipBoardGroupSchema = exports.leadershipBoardFriendSchema = exports.isVowel = exports.isNull = exports.isNotUndefined = exports.isNotNull = exports.isChromeBrowser = exports.isBoolean = exports.incrementTreesSaved = exports.getTreesSavedFromTabsOpened = exports.getTotalTreesSaved = exports.getTotalTabsOpened = exports.getReferralCount = void 0;

require("core-js/modules/es.regexp.exec.js");

require("core-js/modules/es.string.replace.js");

require("core-js/modules/es.regexp.to-string.js");

require("core-js/modules/es.array.reduce.js");

require("core-js/modules/es.number.to-fixed.js");

require("core-js/modules/es.json.stringify.js");

var _Constants = require("./Constants");

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); enumerableOnly && (symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; })), keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = null != arguments[i] ? arguments[i] : {}; i % 2 ? ownKeys(Object(source), !0).forEach(function (key) { _defineProperty(target, key, source[key]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)) : ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

const positionCursorFocus = target => {
  if (target.innerText === "emptyName") target.innerText = "";
  const setpos = document.createRange();
  const set = window.getSelection();
  if (isNotUndefined(target.childNodes[0])) setpos.setStart(target.childNodes[0], target.innerText.length);
  setpos.collapse(true);
  set.removeAllRanges();
  set.addRange(setpos);
  target.focus();
};

exports.positionCursorFocus = positionCursorFocus;

const getTotalTabsOpened = () => {
  const tabsOpenedTillLastWeek = +getLocalStorage(_Constants.STORAGE_CUMMULATIVE_TABS_OPENED);
  const secondsPerTabOpened = +getLocalStorage(_Constants.STORAGE_SECONDS_PER_TAB_OPENED);

  if (!!tabsOpenedTillLastWeek && !!secondsPerTabOpened) {
    const instant = new Date();
    const finalDate = new Date(instant.getUTCFullYear(), instant.getUTCMonth(), instant.getUTCDate(), instant.getUTCHours(), instant.getUTCMinutes(), instant.getUTCSeconds());
    return tabsOpenedTillLastWeek + Math.floor((finalDate - WEEK_START_DATE) / 1000 / secondsPerTabOpened);
  } else return getDefaultTotalTreesSaved() * 5;
};

exports.getTotalTabsOpened = getTotalTabsOpened;
const WEEK_START_DATE = new Date(); // moment().utc().startOf("week").format("YYYY,MM,DD"),

const isChromeBrowser = function isChromeBrowser() {
  let {
    browser = getBrowserType()
  } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return browser === _Constants.CHROME;
};

exports.isChromeBrowser = isChromeBrowser;

const leadershipBoardFriendSchema = function leadershipBoardFriendSchema() {
  let {
    id,
    name,
    score,
    isAdmin = false,
    isSelf = false,
    isFriend = true
  } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return {
    id: id,
    name: name,
    score: score,
    isAdmin: isAdmin,
    isSelf: isSelf,
    isFriend: isFriend
  };
};

exports.leadershipBoardFriendSchema = leadershipBoardFriendSchema;

const leadershipBoardGroupSchema = function leadershipBoardGroupSchema() {
  let {
    id = "",
    name = "",
    score = 0,
    members = [],
    isAdmin = false
  } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return {
    id: id,
    name: name,
    score: score,
    members: members,
    isAdmin: isAdmin
  };
};

exports.leadershipBoardGroupSchema = leadershipBoardGroupSchema;

const fetchQuery = function fetchQuery() {
  let {
    endpoint,
    parameters,
    timeout = 0
  } = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : {};
  return axios.post(endpoint, parameters, {
    timeout: timeout
  }).then(response => response.data).catch(error => {
    var _error$response;

    return (_error$response = error.response) !== null && _error$response !== void 0 && _error$response.data ? error.response.data : error;
  });
};

exports.fetchQuery = fetchQuery;

const copyToClipboard = ref => {
  const input = ref.current;
  input.select();
  input.setSelectionRange(0, 99999);
  navigator.clipboard.writeText(input.value);
};

exports.copyToClipboard = copyToClipboard;

const copyValueToClipboard = value => {
  navigator.clipboard.writeText(value);
};

exports.copyValueToClipboard = copyValueToClipboard;

const validUserId = userId => !!userId && userId.length > 20;

exports.validUserId = validUserId;

const arrayNotEmpty = array => (array === null || array === void 0 ? void 0 : array.length) > 0;

exports.arrayNotEmpty = arrayNotEmpty;

const stringNotEmpty = string => (string === null || string === void 0 ? void 0 : string.length) > 0;

exports.stringNotEmpty = stringNotEmpty;

const isNotNull = value => value !== null;

exports.isNotNull = isNotNull;

const isNull = value => value === null;

exports.isNull = isNull;

const isNotUndefined = value => value !== undefined;

exports.isNotUndefined = isNotUndefined;

const isBoolean = value => value === true || value === false; // removed from leadership board


exports.isBoolean = isBoolean;

const getTreesSavedFromTabsOpened = tabs => Math.floor(tabs / 5);

exports.getTreesSavedFromTabsOpened = getTreesSavedFromTabsOpened;

const NumberFloor = number => Math.floor(number);

exports.NumberFloor = NumberFloor;

const getTotalTreesSaved = () => {
  const initialDate = _Constants.SAVING_TREES_RATE_CHANGED_DATE;
  const instant = new Date();
  const finalDate = new Date(instant.getUTCFullYear(), instant.getUTCMonth(), instant.getUTCDate(), instant.getUTCHours(), instant.getUTCMinutes(), instant.getUTCSeconds());
  return Math.floor(_Constants.GLOBAL_TREES_SAVED_TILL_CHANGED_DATE + Math.floor((finalDate - initialDate) / 1000 / _Constants.DEFAULT_SECONDS_PER_TREE_SAVED));
};

exports.getTotalTreesSaved = getTotalTreesSaved;

const getDefaultTotalTreesSaved = () => {
  const initialDate = _Constants.SAVING_TREES_RATE_CHANGED_DATE;
  const instant = new Date();
  const finalDate = new Date(instant.getUTCFullYear(), instant.getUTCMonth(), instant.getUTCDate(), instant.getUTCHours(), instant.getUTCMinutes(), instant.getUTCSeconds());
  return _Constants.GLOBAL_TREES_SAVED_TILL_CHANGED_DATE + Math.floor((finalDate - initialDate) / 1000 / _Constants.DEFAULT_SECONDS_PER_TREE_SAVED);
};

exports.getDefaultTotalTreesSaved = getDefaultTotalTreesSaved;

const addCommas = number => number === null || number === void 0 ? void 0 : number.toString().replace(/\B(?=(\d{3})+(?!\d))/g, ",");

exports.addCommas = addCommas;

const sumOfScoresInList = list => list.map(object => object.score).reduce((score, accumulator) => score + accumulator, 0);

exports.sumOfScoresInList = sumOfScoresInList;

const numberOfAdsToTreeSaved = numberOfAds => {
  switch (numberOfAds) {
    case 0:
      {
        return 1 / 50;
      }

    case 1:
      {
        return 1 / 10;
      }

    case 2:
      {
        return 1 / 8;
      }

    case 3:
      {
        return 1 / 5;
      }

    default:
      {
        // Return treesSaved itself, if source is sponsored-survey
        return numberOfAds;
      }
  }
};

const numberOfAdsToTreeSavedSource = numberOfAds => {
  return 1;
};

exports.numberOfAdsToTreeSavedSource = numberOfAdsToTreeSavedSource;

const incrementTreesSaved = _ref => {
  let {
    user,
    advertisementCount,
    adsWhitelisted
  } = _ref;
  const {
    treesSaved
  } = user;
  const treeSaved = adsWhitelisted ? numberOfAdsToTreeSaved(advertisementCount) : numberOfAdsToTreeSaved(0);
  let updatedTreesSaved = treesSaved + treeSaved;
  if (getPercentageOfTreeSaved(updatedTreesSaved) > 95 && adsWhitelisted) updatedTreesSaved = Math.ceil(updatedTreesSaved);
  user = _objectSpread(_objectSpread({}, user), {}, {
    treesSaved: updatedTreesSaved
  });
  return user;
};

exports.incrementTreesSaved = incrementTreesSaved;

const getPercentageOfTreeSaved = treesSaved => {
  const lowerBit = Math.floor(treesSaved);
  const percent = (treesSaved - lowerBit) * 100;
  return +percent.toFixed(0);
};

exports.getPercentageOfTreeSaved = getPercentageOfTreeSaved;

const isVowel = word => word !== undefined ? ["a", "e", "i", "o", "u"].indexOf(word.charAt(0).toLowerCase()) !== -1 : false;

exports.isVowel = isVowel;

const getReferralCount = referrals => referrals === null || referrals === void 0 ? void 0 : referrals.length;

exports.getReferralCount = getReferralCount;

const sumOfTreesInList = list => list.map(object => object.treesSaved).reduce((score, accumulator) => score + accumulator, 0);

exports.sumOfTreesInList = sumOfTreesInList;

const treesToCO2Stored = trees => NumberFloor(trees * _Constants.CO2_STORED_PER_TREE);

exports.treesToCO2Stored = treesToCO2Stored;

const setLocalStorage = (key, value) => localStorage.setItem(key, value);

exports.setLocalStorage = setLocalStorage;

const getLocalStorage = key => localStorage.getItem(key); // export const getTabsOpenedTodayFromStorage = () => {
// 	const tabsOpenedString = localStorage.getItem(STORAGE_RECENT_DAY_TABS_OPENED);
// 	const tabsOpenedParsed = parseInt(tabsOpenedString, 10);
// 	const tabsOpened = isNaN(tabsOpenedParsed) ? 0 : tabsOpenedParsed;
// 	return tabsOpened;
// };


exports.getLocalStorage = getLocalStorage;

function getBrowserType() {
  const userDeviceDetails = navigator.userAgent;
  const userAgentString = userDeviceDetails;
  let chromeAgent = userAgentString.indexOf("Chrome") > -1;
  let edgeAgent = userAgentString.indexOf("Edg") > -1;
  let firefoxAgent = userAgentString.indexOf("Firefox") > -1;
  let safariAgent = userAgentString.indexOf("Safari") > -1; // Discard Chrome since it also matches Edge

  if (chromeAgent && edgeAgent) chromeAgent = false; // Discard Safari since it also matches Chrome

  if (chromeAgent && safariAgent) safariAgent = false;
  return chromeAgent ? "chrome" : edgeAgent ? "edge" : firefoxAgent ? "firefox" : safariAgent ? "safari" : "chrome";
}

function getPostHeader(data) {
  return {
    method: "POST",
    headers: {
      "Content-Type": "application/json"
    },
    body: JSON.stringify(data)
  };
}